@@ -3,11 +3,12 @@ import unittest
 
 import httpx
 
-from feishu.messages import FeiShuBot
+from feishu import FeiShuBot
 
 
 class TestFeishu(unittest.TestCase):
-    bot = FeiShuBot()
+    def setUp(self) -> None:
+        self.bot = FeiShuBot()
 
     def test_send_text(self):
         self.bot.send_text("This is a test message.")
